Dataset classes
===============

Dataset base class
-------------------
.. autoclass:: tonic.Dataset
    :members:
    :private-members:

Caching
-------
.. autoclass:: tonic.MemoryCachedDataset
    :members:

.. autoclass:: tonic.DiskCachedDataset
    :members:

.. autoclass:: tonic.CachedDataset
    :members:

Slicing
-------
.. autoclass:: tonic.SlicedDataset
    :members:
